@@ -1,4 +1,4 @@
-/*	$Id: icb.c,v 1.12 2003/12/06 14:39:14 dhartmei Exp $ */
+/*	$Id: icb.c,v 1.13 2004/01/04 00:08:07 dhartmei Exp $ */
 
 /*
  * Copyright (c) 2003 Daniel Hartmeier
@@ -30,7 +30,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: icb.c,v 1.12 2003/12/06 14:39:14 dhartmei Exp $";
+static const char rcsid[] = "$Id: icb.c,v 1.13 2004/01/04 00:08:07 dhartmei Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -563,6 +563,8 @@ icb_send_hw(int fd, const char *arg)
 void
 icb_send_list(int fd)
 {
+	if (imode != imode_none)
+		return;
 	imode = imode_list;
 	icb_send_hw(fd, "-g");
 }
@@ -570,14 +572,18 @@ icb_send_list(int fd)
 void
 icb_send_names(int fd, const char *group)
 {
+	if (imode != imode_none)
+		return;
 	imode = imode_names;
 	strlcpy(igroup, group, sizeof(igroup));
-	icb_send_hw(fd, group[0] == '#' ? group + 1 : group);
+	icb_send_hw(fd, "");
 }
 
 void
 icb_send_whois(int fd, const char *nick)
 {
+	if (imode != imode_none)
+		return;
 	imode = imode_whois;
 	strlcpy(inick, nick, sizeof(inick));
 	icb_send_hw(fd, "");
@@ -586,6 +592,8 @@ icb_send_whois(int fd, const char *nick)
 void
 icb_send_who(int fd, const char *hostmask)
 {
+	if (imode != imode_none)
+		return;
 	imode = imode_who;
 	strlcpy(ihostmask, hostmask, sizeof(ihostmask));
 	icb_send_hw(fd, "");
